///////////////////////////////////////////////////////////////////////////////
// FileDatagroupRecord.h
// Paul Wilson
// Oxford Metrics, May 2000
///////////////////////////////////////////////////////////////////////////////

#pragma once

#include <string>
#include <vector>
#include <cassert>

#include "FileRecord.h"
#include "Definitions.h"

class VFileDynamicRecord;

class VFileDatagroupRecord : public VFileRecord
{
private:		
	SSHORT		m_GroupID;
	std::string	m_strDesc;
	EDataType	m_DataType;
	BYTE		m_DataWidth;
	float		m_FrameRate;
	std::vector<std::string> m_Labels;

	std::vector<VFileDynamicRecord *> m_DynRecs;

public:
	VFileDatagroupRecord(SSHORT a_ID, EDataType a_Type, BYTE a_DataWidth, float a_FrameRate);
	VFileDatagroupRecord(BYTE * a_RawData, short a_sRecLen);
	virtual ~VFileDatagroupRecord();

	// "Get" functions

	SSHORT		GetGroupID() const		{ return m_GroupID; }
	std::string GetDescription() const	{ return m_strDesc; }
	EDataType	GetDataType() const		{ return m_DataType; }
	std::string GetDataTypeAsString() const;
	BYTE		GetDataWidth() const	{ return m_DataWidth; }
	float		GetFrameRate() const	{ return m_FrameRate; }
	const std::vector<std::string> & GetLabels() const	{ return m_Labels; }
	SSHORT		GetNumEntries() const	{ return m_Labels.size(); }
//	const std::vector<VFileDynamicRecord *> GetDynamicRecords() const { return m_DynRecs; }

	// "Set" functions

	void SetGroupID(SSHORT a_ID);
	void SetDescription(std::string a_strDesc);
	void SetDataType(EDataType a_DataType);
	void SetDataWidth(BYTE a_Width);
	void SetFrameRate(float a_FrameRate);
	void DeleteLabel(int a_Index);
	void AddLabel(std::string a_strNewLabel);
	void InsertLabel(std::string a_strNewLabel, int a_Index);
	void SetLabelAt(std::string a_strNewLabel, int a_Index);
	void DeleteDynamicRecord(int a_Index);
	void AddDynamicRecord(VFileDynamicRecord * a_pRec);
	void InsertDynamicRecord(VFileDynamicRecord * a_pRec, int a_Index);
	void SetDynamicRecordAt(VFileDynamicRecord * a_pRec, int a_Index);


	virtual int CalculateLength() const; 

	virtual void BuildRecordFromBytes();
	virtual SSHORT BuildBytesFromRecord();
};

