// VDOFLocator.cpp: implementation of the VDOFLocator class.
//
//////////////////////////////////////////////////////////////////////

#include <maya/MPxLocatorNode.h> 
#include "SpaceLocator.h"

#if defined(OSMac_MachO_)
#include <OpenGL/gl.h>
#include <OpenGL/glu.h>
#else
#include <GL/gl.h>
#include <GL/glu.h>

#endif
MTypeId VDOFLocator::id( 0x66666 );
MObject VDOFLocator::size;


MStatus VDOFLocator::compute( const MPlug& plug, MDataBlock& data )
{ 
	return MS::kUnknownParameter;
}


void VDOFLocator::draw(M3dView & view, const MDagPath &path,
                                 M3dView::DisplayStyle style,
                                 M3dView::DisplayStatus status)
{
	MObject thisNode = thisMObject();
	MPlug plug( thisNode, size );
	MDistance sizeVal;
	plug.getValue( sizeVal );

	// We want it to be the correct size regardless of the internal units.

	MDistance UnitMultiplier(10.0, MDistance::kCentimeters);
	MDistance::Unit CurrentUnits = MDistance::internalUnit();
	float Multiplier = UnitMultiplier.as(CurrentUnits);

	view.beginGL();

	if (style == M3dView::kFlatShaded || style == M3dView::kGouraudShaded) 
	{
		// Push the color settings
		glPushAttrib(GL_CURRENT_BIT);

		if(status == M3dView::kActive)
			view.setDrawColor(13, M3dView::kActiveColors);
		else 
			view.setDrawColor(9, M3dView::kDormantColors);

		glEnd();
		glPopAttrib();
    }

	int i;

	glBegin( GL_LINES );

	for (i = 0; i < vertexCount; i++)
	{
		glVertex3f(0.0f, 0.0f, 0.5f * Multiplier);
		glVertex3f(0.0f, 0.0f, -0.5f * Multiplier);
		glVertex3f(0.5f * Multiplier, 0.0f, 0.0f);
		glVertex3f(-0.5f * Multiplier, 0.0f, 0.0f);

		glVertex3f(0.0f, 0.5f * Multiplier, 0.0f);
		glVertex3f(0.0f, -0.5f * Multiplier, 0.0f);
	}

	glEnd();
	view.endGL();
}

bool VDOFLocator::isBounded() const
{ 
	return false;
}

MBoundingBox VDOFLocator::boundingBox() const
{
	MObject thisNode = thisMObject();
	MPlug plug( thisNode, size );
	MDistance sizeVal;
	plug.getValue( sizeVal );

	double Multiplier = sizeVal.asCentimeters();
	MPoint corner1(-0.5, 0.0, -0.5);
	MPoint corner2(0.5, 0.0, 0.5);

	corner1 = corner1 * Multiplier;
	corner2 = corner2 * Multiplier;

	return MBoundingBox(corner1, corner2);
}

void * VDOFLocator::creator()
{
	return new VDOFLocator();
}

MStatus VDOFLocator::initialize()
{ 
	MFnUnitAttribute unitFn;
	MStatus			 stat;

	size = unitFn.create( "size", "sz", MFnUnitAttribute::kDistance );
	unitFn.setDefault( 1.0 );

	stat = addAttribute( size );
	if (!stat) {
		stat.perror("addAttribute");
		return stat;
	}
	
	return MS::kSuccess;
}


MTypeId VMarkerLocator::id( 0x66667 );
MObject VMarkerLocator::size;

void * VMarkerLocator::creator()
{
	return new VMarkerLocator();
}

void VMarkerLocator::draw(M3dView & view, const MDagPath &path,
                                 M3dView::DisplayStyle style,
                                 M3dView::DisplayStatus status)
{
	MObject thisNode = thisMObject();
	MPlug plug( thisNode, size );
	MDistance sizeVal;
	plug.getValue( sizeVal );

	// We want it to be the correct size regardless of the internal units.

	MDistance UnitMultiplier(2.0, MDistance::kCentimeters);
	MDistance::Unit CurrentUnits = MDistance::internalUnit();
	float Multiplier = UnitMultiplier.as(CurrentUnits);

	view.beginGL();

	if (style == M3dView::kFlatShaded || style == M3dView::kGouraudShaded) 
	{
		// Push the color settings
		glPushAttrib(GL_CURRENT_BIT);

		if(status == M3dView::kActive)
			view.setDrawColor(13, M3dView::kActiveColors);
		else 
			view.setDrawColor(9, M3dView::kDormantColors);

		glEnd();
		glPopAttrib();
    }

	int i;

	glBegin( GL_LINES );

	for (i = 0; i < vertexCount; i++)
	{
		glVertex3f(0.0f, 0.0f, 0.5f * Multiplier);
		glVertex3f(0.0f, 0.0f, -0.5f * Multiplier);
		glVertex3f(0.5f * Multiplier, 0.0f, 0.0f);
		glVertex3f(-0.5f * Multiplier, 0.0f, 0.0f);

		glVertex3f(0.0f, 0.5f * Multiplier, 0.0f);
		glVertex3f(0.0f, -0.5f * Multiplier, 0.0f);
	}

	glEnd();
	view.endGL();
}

